import sys
import os
import logging
from openpyxl import load_workbook
import xml.etree.ElementTree as ET
from xml.dom import minidom

def setup_logger(input_path):
    """Настройка логгера с записью в исходную папку"""
    log_dir = os.path.dirname(input_path)
    log_file = os.path.join(log_dir, "xlsx2xml.log")
    
    
    # Конфигурация логгера
    # INFO: Основные этапы процесса;
    # DEBUG: Детали операций (чтение ячеек, запись файла);
    # ERROR: Критические ошибки с трейсбэком (exc_info=True)
    
    logging.basicConfig(
        level=logging.DEBUG,
        format="%(asctime)s - %(levelname)s - %(message)s",
        handlers=[
            logging.FileHandler(log_file, encoding='utf-8'),
            logging.StreamHandler()
        ]
    )
    return logging.getLogger()

def convert_xlsx_to_xml(input_path, output_path, logger):
    """Конвертация XLSX в XML с логированием"""
    try:
        logger.info(f"Старт конвертации: {input_path} -> {output_path}")
        
        # Загрузка XLSX
        logger.debug("Открытие XLSX-файла")
        wb = load_workbook(input_path)
        sheet = wb.active

        # Извлечение данных
        logger.debug("Чтение данных из ячеек")
        data = {
            "Customer": sheet["B2"].value,
            "ProductName": sheet["C2"].value,
            "OrderID": sheet["B4"].value,
            "Comment": sheet["C4"].value,
            "Article": sheet["B6"].value,
            "Width": sheet["B8"].value,
            "PrintStep": sheet["B10"].value,
            "StreamsCount": sheet["B12"].value,
            "BaseArticle": sheet["B14"].value
        }

        # Генерация XML
        logger.debug("Создание XML-структуры")
        root = ET.Element("Order")
        for key, value in data.items():
            ET.SubElement(root, key).text = str(value or "")

        # Сохранение
        logger.debug("Запись XML-файла")
        xml_str = minidom.parseString(ET.tostring(root)).toprettyxml()
        with open(output_path, "w", encoding="utf-8") as f:
            f.write(xml_str)

        logger.info(f"Успешно сохранено: {output_path}")
        return 0

    except Exception as e:
        logger.error(f"Ошибка конвертации: {str(e)}", exc_info=True)
        return 1

if __name__ == "__main__":
    if len(sys.argv) != 3:
        print("Использование: python xlsx2xml.py <input.xlsx> <output.xml>")
        sys.exit(1)
    
    # Инициализация логгера
    logger = setup_logger(sys.argv[1])
    
    # Запуск конвертации
    exit_code = convert_xlsx_to_xml(sys.argv[1], sys.argv[2], logger)
    sys.exit(exit_code)